/* ***********************************************************************
**
**  Copyright (C) 2005  Christian Kranz
**
**  Siemens S65 Display Control
**
*********************************************************************** */
// disp.h
#ifndef _DISP_H
#define _DISP_H

#define DISP_W 132
#define DISP_H 176
#define CHAR_H 14
#define CHAR_W 8
#define TEXT_COL 16
#define TEXT_ROW 12



#define LCD_CS	   PB0
#define LCD_RESET  PB6
#define LCD_RS	   PB7
#define LCD_MOSI   PB2
#define LCD_MISO   PB3
#define LCD_SCK    PB1



#define DATCTL 0xBC         // Data Control (data handling in RAM)
#define DISCTL 0xCA         // Display Control
#define GCP64 0xCB          // pulse set for 64 gray scale
#define GCP16 0xCC          // pulse set for 16 gray scale
#define OSSEL 0xD0          // Oscillator select
#define GSSET 0xCD          // set for gray scales
#define ASCSET 0xAA         // aerea scroll setting
#define SCSTART 0xAB        // scroll start setting
#define DISON 0xAF          // Display ON (no parameter)
#define DISOFF 0xAE         // Display OFF (no parameter)
#define DISINV 0xA7         // Display Invert (no parameter)
#define DISNOR 0xA6         // Display Normal (no parameter)
#define SLPIN  0x95         // Display Sleep (no parameter)
#define SLPOUT 0x94         // Display out of sleep (no parameter)
#define RAMWR 0x5C          // Display Memory write
#define PTLIN 0xA8          // partial screen write

#define SD_CSET 0x15        // column address setting
#define SD_PSET 0x75        // page address setting



#define RSTHi (GPIOC->BSRR=GPIO_BSRR_BS2) 
#define RSTLow (GPIOC->BSRR=GPIO_BSRR_BR2) 
#define RSHi (GPIOC->BSRR=GPIO_BSRR_BS3) 
#define RSLow (GPIOC->BSRR=GPIO_BSRR_BR3)
#define CSHi (GPIOC->BSRR=GPIO_BSRR_BS1) 
#define CSLow (GPIOC->BSRR=GPIO_BSRR_BR1)

#define Set_PortC_Pin_1_output ((GPIOC->CRL |= 0x30)|(GPIOC->CRL &= ~0xC0))  				
#define Set_PortC_Pin_2_output ((GPIOC->CRL |= 0x300)|(GPIOC->CRL &= ~0xC00))
#define Set_PortC_Pin_3_output ((GPIOC->CRL |= 0x3000)|(GPIOC->CRL &= ~0xC000))

#define Set_PortC_Pin_8_output ((GPIOC->CRH |= 0x3)|(GPIOC->CRH &= ~0xC))
#define Set_PortC_Pin_9_output ((GPIOC->CRH |= 0x30)|(GPIOC->CRH &= ~0xC0))

#define GreenLedOn (GPIOC->BSRR=GPIO_BSRR_BS9) 
#define GreenLedOff (GPIOC->BSRR=GPIO_BSRR_BR9) 
#define BlueLedOn (GPIOC->BSRR=GPIO_BSRR_BS8) 
#define BlueLedOff (GPIOC->BSRR=GPIO_BSRR_BR8)





extern uint16_t textcolor;    // color of text
extern uint16_t backcolor;    // color of background



/////////////////////////////// function prototypes ////////////////////////

void port_init(void);

void lcd_write(uint8_t);
void lcd_cmd(uint8_t dat);
void lcd_dat0(uint8_t dat);
void lcd_dat16(uint16_t dat);

void lcd_init_c(void);
void fill_screen(uint16_t color);
void put_char(uint8_t x, uint8_t y, char c, uint8_t rot);
void delay_ms(int i);

#endif
// end of file disp.h
